Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(511)

Unified Diff: content/browser/browser_thread_impl.cc

Issue 2873333004: Rename TaskRunner::RunsTasksOnCurrentThread() in //content (Closed)
Patch Set: Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | content/browser/byte_stream.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/browser_thread_impl.cc
diff --git a/content/browser/browser_thread_impl.cc b/content/browser/browser_thread_impl.cc
index fa8e491119cfffc89f5c801bf776a599bfc757a7..205340ed3016e71b684936918a4801ea8e3f5d3b 100644
--- a/content/browser/browser_thread_impl.cc
+++ b/content/browser/browser_thread_impl.cc
@@ -133,7 +133,7 @@ struct BrowserThreadGlobals {
// This array is filled either as the underlying threads start and invoke
// Init() or in RedirectThreadIDToTaskRunner() for threads that are being
// redirected. It is not emptied during shutdown in order to support
// RunsTasksOnCurrentThread() until the very end.
scoped_refptr<base::SingleThreadTaskRunner>
task_runners[BrowserThread::ID_COUNT];
@@ -208,7 +208,7 @@ void BrowserThreadImpl::Init() {
// instead of BrowserThreadImpl::Start.*().
DCHECK_EQ(globals.states[identifier_], BrowserThreadState::RUNNING);
DCHECK(globals.task_runners[identifier_]);
- DCHECK(globals.task_runners[identifier_]->RunsTasksOnCurrentThread());
+ DCHECK(globals.task_runners[identifier_]->RunsTasksInCurrentSequence());
}
#endif // DCHECK_IS_ON()
@@ -574,7 +574,7 @@ bool BrowserThread::CurrentlyOn(ID identifier) {
DCHECK_GE(identifier, 0);
DCHECK_LT(identifier, ID_COUNT);
return globals.task_runners[identifier] &&
- globals.task_runners[identifier]->RunsTasksOnCurrentThread();
+ globals.task_runners[identifier]->RunsTasksInCurrentSequence();
}
// static
@@ -661,7 +661,7 @@ bool BrowserThread::GetCurrentThreadIdentifier(ID* identifier) {
base::AutoLock lock(globals.lock);
for (int i = 0; i < ID_COUNT; ++i) {
if (globals.task_runners[i] &&
- globals.task_runners[i]->RunsTasksOnCurrentThread()) {
+ globals.task_runners[i]->RunsTasksInCurrentSequence()) {
*identifier = static_cast<ID>(i);
return true;
}
@@ -133,7 +133,7 @@ struct BrowserThreadGlobals {
// Init() or in RedirectThreadIDToTaskRunner() for threads that are being
// redirected. It is not emptied during shutdown in order to support
- // RunsTasksOnCurrentThread() until the very end.
+ // RunsTasksInCurrentSequence() until the very end.
scoped_refptr<base::SingleThreadTaskRunner>
task_runners[BrowserThread::ID_COUNT];
« no previous file with comments | « no previous file | content/browser/byte_stream.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698